pub trait Action<'a> {
// Required method
fn execute(&self) -> Result<(), DotfilesError>;
}Expand description
An action to be run by a the dotfiles runtime.
Required Methods
Sourcefn execute(&self) -> Result<(), DotfilesError>
fn execute(&self) -> Result<(), DotfilesError>
Executes the action.
Returns an error String describing the issue, this string can be used to log or display to the user.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".